==> nextcloud-21.0.8.tgz: nextcloud/apps/privacy/l10n/ja.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "プライバシー",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "プライバシーセンターでは、あなたのデータがどこに保存され、誰がそれにアクセスできるか、あなたがどういうデータを共有しているのか、それとも管理者からであるのかのを示します。",
    "Remove external admin" : "外部管理者を削除",
    "Add external admin" : "外部管理者を追加",
    "Name of external admin" : "外部管理者名",
    "This server is using full-disk-encryption." : "このサーバーはフルディスク暗号化を使用しています。",
    "Additionally, this server is protected with full-disk-encryption." : "更にこのサーバーは、ディスク全体の暗号化により保護されています。",
    "This server is protected with full-disk-encryption." : "このサーバーはフルディスク暗号化で保護されています。",
    "Your files are not protected by encryption." : "ファイルは暗号化されていません。",
    "Your data is located in:" : "あなたのデータは以下の場所にあります:",
    "Change data location" : "データの保存場所を変更",
    "Please select a region" : "地域を選択してください",
    "You don't have any shares with individual users." : "個別のユーザーとの共有はありません",
    "Somaliland" : "ソマリランド",
    "Andorra" : "アンドラ",
    "United Arab Emirates" : "アラブ首長国連邦",
    "Afghanistan" : "アフガニスタン",
    "Antigua and Barbuda" : "アンティグア・バーブーダ",
    "Anguilla" : "アンギラ",
    "Albania" : "アルバニア",
    "Armenia" : "アルメニア",
    "Angola" : "アンゴラ",
    "Antarctica" : "南極大陸",
    "Argentina" : "アルゼンチン",
    "American Samoa" : "アメリカ領サモア",
    "Austria" : "オーストリア",
    "Australia" : "オーストラリア",
    "Aruba" : "アルバ",
    "Åland Islands" : "オーランド諸島",
    "Azerbaijan" : "アゼルバイジャン",
    "Bosnia and Herzegovina" : "ボスニア・ヘルツェゴビナ",
    "Barbados" : "バルバドス",
    "Bangladesh" : "バングラデシュ",
    "Belgium" : "ベルギー",
    "Burkina Faso" : "ブルキナファソ",
    "Bulgaria" : "ブルガリア",
    "Bahrain" : "バーレーン",
    "Burundi" : "ブルンジ共和国",
    "Benin" : "ベナン",
    "Saint Barthélemy" : "サン・バルテルミー島",
    "Bermuda" : "バミューダ諸島",
    "Brunei" : "ブルネイ",
    "Bolivia" : "ボリビア",
    "Bonaire, Sint Eustatius and Saba" : "ボネール、シント・ユースタティウスおよびサバ",
    "Brazil" : "ブラジル",
    "Bahamas" : "バハマ",
    "Bhutan" : "ブータン",
    "Bouvet Island" : "ブーベ島",
    "Botswana" : "ボツワナ",
    "Belarus" : "ベラルーシ",
    "Belize" : "ベリーズ",
    "Canada" : "カナダ",
    "Cocos (Keeling) Islands" : "ココス諸島",
    "Democratic Republic of the Congo" : "コンゴ民主共和国",
    "Central African Republic" : "中央アフリカ共和国",
    "Congo" : "コンゴ共和国",
    "Switzerland" : "スイス",
    "Cote d'Ivoire" : "コートジボワール",
    "Cook Islands" : "クック諸島",
    "Chile" : "チリ",
    "Cameroon" : "カメルーン",
    "China" : "中華人民共和国",
    "Colombia" : "コロンビア共和国",
    "Costa Rica" : "コスタリカ",
    "Cuba" : "キューバ",
    "Cabo Verde" : "カーボベルデ",
    "Curaçao" : "キュラソー島",
    "Christmas Island" : "クリスマス諸島",
    "Cyprus" : "キプロス共和国",
    "Czech" : "チェコ共和国",
    "Germany" : "ドイツ",
    "Djibouti" : "ジブチ",
    "Denmark" : "デンマーク",
    "Dominican Republic" : "ドミニカ共和国",
    "Algeria" : "アルジェリア民主人民共和国",
    "Ecuador" : "エクアドル",
    "Estonia" : "エストニア",
    "Egypt" : "エジプト",
    "West Sahara" : "西サハラ",
    "Eritrea" : "エリトリア",
    "Spain" : "スペイン",
    "Ethiopia" : "エチオピア",
    "Finland" : "フィンランド",
    "Fiji" : "フィジー",
    "Falkland Islands" : "フォークランド諸島",
    "Micronesia" : "ミクロネシア",
    "Faroe Islands" : "フェロー諸島",
    "France" : "フランス",
    "Gabon" : "ガボン",
    "United Kingdom" : "イギリス",
    "Grenada" : "グレナダ",
    "Georgia" : "ジョージア",
    "French Guiana" : "フランス領ギアナ",
    "Guernsey" : "ガーンジー",
    "Ghana" : "ガーナ",
    "Gibraltar" : "ジブラルタル",
    "Greenland" : "グリーンランド",
    "Gambia" : "ガンビア",
    "Guinea" : "ギニア共和国",
    "Guadeloupe" : "グアドループ",
    "Equatorial Guinea" : "赤道ギニア共和国",
    "Greece" : "ギリシャ",
    "South Georgia and the South Sandwich Islands" : "サウスジョージア・サウスサンドウィッチ諸島",
    "Guatemala" : "グアテマラ",
    "Guam" : "グアム",
    "Guinea-Bissau" : "ギニアビサウ共和国",
    "Guyana" : "ガイアナ",
    "Honduras" : "ホンジュラス",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "ハード島とマクドナルド諸島",
    "Croatia" : "クロアチア",
    "Haiti" : "ハイチ",
    "Hungary" : "ハンガリー",
    "Indonesia" : "インドネシア",
    "Ireland" : "アイルランド",
    "Israel" : "イスラエル",
    "Isle of Man" : "マン島",
    "India" : "インド",
    "British Indian Ocean Territory" : "イギリス領インド洋地域",
    "Iraq" : "イラク",
    "Iran" : "イラン",
    "Iceland" : "アイスランド",
    "Italy" : "イタリア",
    "Jamaica" : "ジャマイカ",
    "Jordan" : "ヨルダン・ハシミテ王国",
    "Japan" : "日本",
    "Kenya" : "ケニア",
    "Kyrgyzstan" : "キルギス",
    "Cambodia" : "カンボジア",
    "Kiribati" : "キリバス",
    "Comores" : "コモロ",
    "Saint Kitts and Nevis" : "セントクリストファー・ネイビス",
    "North Korea" : "朝鮮民主主義人民共和国",
    "South Korea" : "大韓民国",
    "Kuwait" : "クウェート",
    "Cayman Islands" : "ケイマン諸島",
    "Kazakhstan" : "カザフスタン",
    "Laos" : "ラオス",
    "Lebanon" : "レバノン",
    "Saint Lucia" : "セントルシア",
    "Liechtenstein" : "リヒテンシュタイン",
    "Sri Lanka" : "スリランカ",
    "Liberia" : "リベリア",
    "Lesotho" : "レソト",
    "Lithuania" : "リトアニア",
    "Luxembourg" : "ルクセンブルク",
    "Latvia" : "ラトビア",
    "Libya" : "リビア",
    "Morocco" : "モロッコ",
    "Monaco" : "モナコ",
    "Moldova" : "モルドバ",
    "Montenegro" : "モンテネグロ",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "マダガスカル",
    "Marshall Islands" : "マーシャル諸島",
    "Macedonia" : "北マケドニア共和国",
    "Mali" : "マリ",
    "Myanmar" : "ミャンマー",
    "Mongolia" : "モンゴル",
    "Macao" : "マカオ",
    "Northern Mariana Islands" : "北マリアナ諸島",
    "Mauritania" : "モーリタニア",
    "Montserrat" : "モントセラト",
    "Malta" : "マルタ",
    "Mauritius" : "モーリシャス",
    "Maldives" : "モルディブ",
    "Malawi" : "マラウイ共和国",
    "Mexico" : "メキシコ",
    "Malaysia" : "マレーシア",
    "Mozambique" : "モザンビーク",
    "Namibia" : "ナミビア",
    "New Caledonia" : "ニューカレドニア",
    "Niger" : "ニジェール",
    "Norfolk Island" : "ノーフォーク島",
    "Nigeria" : "ナイジェリア",
    "Nicaragua" : "ニカラグア",
    "Netherlands" : "オランダ",
    "Norway" : "ノルウェー",
    "Nepal" : "ネパール",
    "Nauru" : "ナウル",
    "Niue" : "ニウエ",
    "New Zealand" : "ニュージーランド",
    "Oman" : "オマーン",
    "Panama" : "パナマ",
    "Peru" : "ペルー",
    "French Polynesia" : "フランス領ポリネシア",
    "Papua New Guinea" : "パプアニューギニア",
    "Philippines" : "フィリピン",
    "Pakistan" : "パキスタン",
    "Poland" : "ポーランド",
    "Saint Pierre and Miquelon" : "サンピエール島・ミクロン島",
    "Pitcairn" : "ピトケアン諸島",
    "Puerto Rico" : "プエルトリコ",
    "Palestine" : "パレスチナ",
    "Portugal" : "ポルトガル",
    "Palau" : "パラオ",
    "Paraguay" : "パラグアイ",
    "Qatar" : "カタール",
    "Réunion" : "レユニオン",
    "Romania" : "ルーマニア",
    "Serbia" : "セルビア",
    "Russia" : "ロシア",
    "Rwanda" : "ルワンダ",
    "Saudi Arabia" : "サウジアラビア",
    "Solomon Islands" : "ソロモン諸島",
    "Seychelles" : "セーシェル",
    "Sudan" : "スーダン",
    "Sweden" : "スウェーデン",
    "Singapore" : "シンガポール",
    "Saint Helena, Ascension and Tristan da Cunha" : "セントヘレナ・アセンションおよびトリスタンダクーニャ",
    "Slovenia" : "スロベニア",
    "Svalbard and Jan Mayen" : "スヴァールバル諸島およびヤンマイエン島",
    "Slovakia" : "スロバキア",
    "Sierra Leone" : "シエラレオネ",
    "San Marino" : "サンマリノ",
    "Senegal" : "セネガル",
    "Somalia" : "ソマリア",
    "Suriname" : "スリナム",
    "South Sudan" : "南スーダン",
    "Sao Tome and Principe" : "サントメ・プリンシペ",
    "El Salvador" : "エルサルバドル",
    "Sint Maarten" : "シント・マールテン",
    "Syria" : "シリア",
    "Swaziland" : "スワジランド",
    "Turks and Caicos Islands" : "タークス・カイコス諸島",
    "Chad" : "チャド",
    "Fr. S. Antarctic Lands" : "フランスの南方・南極地域",
    "Togo" : "トーゴ",
    "Thailand" : "タイ",
    "Tajikistan" : "タジキスタン",
    "Tokelau" : "トケラウ",
    "Timor-Leste" : "東ティモール",
    "Turkmenistan" : "トルクメニスタン",
    "Tunisia" : "チュニジア",
    "Tonga" : "トンガ",
    "Turkey" : "トルコ",
    "Trinidad and Tobago" : "トリニダード・トバゴ",
    "Tuvalu" : "ツバル",
    "Taiwan" : "台湾",
    "Tanzania" : "タンザニア",
    "Ukraine" : "ウクライナ",
    "Uganda" : "ウガンダ",
    "United States Minor Outlying Islands" : "合衆国領有小離島",
    "United States" : "アメリカ",
    "Uruguay" : "ウルグアイ",
    "Uzbekistan" : "ウズベキスタン",
    "Holy See" : "バチカン",
    "Saint Vincent and the Grenadines" : "セントビンセント・グレナディーン",
    "Venezuela" : "ベネズエラ",
    "Virgin Islands (British)" : "イギリス領ヴァージン諸島",
    "Virgin Islands (U.S.)" : "アメリカ領ヴァージン諸島",
    "Vietnam" : "ベトナム",
    "Vanuatu" : "バヌアツ",
    "Wallis and Futuna" : "ウォリス・フツナ",
    "Samoa" : "サモア",
    "Yemen" : "イエメン",
    "Mayotte" : "マヨット",
    "South Africa" : "南アフリカ",
    "Zambia" : "ザンビア",
    "Zimbabwe" : "ジンバブエ",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "あなたのデータにはあなたに関する情報が含まれており、簡単に悪用される可能性があります。 Nextcloudでは、あなたがあなたのデータで何が起こるかを決める権利があると信じています。 Nextcloudはユーザーデータマニフェストで定義されているようにあなたの権利を保護します！",
    "User Data Manifesto 2.0" : "ユーザーデータマニフェスト2.0",
    "Defining basic rights for people to control their own data in the internet age" : "インターネット時代に人々が自分のデータを管理するための基本的権利を定義する",
    "Control" : "コントロール",
    "over user data access" : "ユーザーデータアクセス経由",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "ユーザーによって明示的かつ意図的にアップロードされたデータは、ユーザーの最終的な管理下にあるべきです。ユーザーは、自分のデータへの直接アクセスを誰に許可するのか、およびどのアクセス権とライセンスでアクセスを許可するのかを決定できる必要があります。",
    "Knowledge" : "知見",
    "of how the data is stored" : "データの格納方法",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "データが特定のサービスプロバイダーにアップロードされるとき、ユーザーはその特定のサービスプロバイダーがデータをどのくらいの期間、どこに保存するのか、サービスプロバイダーが運営している地域、そしてどの法律が適用されるかについて知らされるべきです。",
    "Freedom" : "自由",
    "to choose a platform" : "プラットフォームを選択する",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "ユーザーはベンダーのロックインを経験することなく、いつでも自分のデータを抽出することができるはずです。これを保証するためにオープンスタンダードなフォーマットとプロトコルが必要です。",
    "Learn more ↗" : "もっと詳しく知る",
    "Where is your data?" : "データはどこにありますか？",
    "Who has access to your data?" : "誰があなたのデータにアクセスできますか？",
    "Administrators" : "管理者",
    "People you shared with" : "あなたが共有した人",
    "Privacy policy" : "個人情報保護方針",
    "Read the privacy policy." : "個人情報保護方針を読んでください。",
    "Encryption" : "暗号化",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "あなたのファイルは {linkopen}サーバーサイド暗号化↗{linkclose} で暗号化されています。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "あなたのファイルは {linkopen}サーバーサイド暗号化↗{linkclose} で暗号化されています。さらに、このサーバーはフルディスク暗号化で保護されています。",
    "Your data is located in: " : "データは以下に格納:",
    "The admin hasn't selected the location of the server yet." : "管理者はまだサーバーの場所を選択していません。"
},
"nplurals=1; plural=0;");

==> nextcloud-22.2.1.tgz: nextcloud/apps/privacy/l10n/ja.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "プライバシー",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "プライバシーセンターでは、あなたのデータがどこに保存され、誰がそれにアクセスできるか、あなたがどういうデータを共有しているのか、それとも管理者からであるのかのを示します。",
    "Remove external admin" : "外部管理者を削除",
    "Add external admin" : "外部管理者を追加",
    "Name of external admin" : "外部管理者名",
    "This server is using full-disk-encryption." : "このサーバーはフルディスク暗号化を使用しています。",
    "Additionally, this server is protected with full-disk-encryption." : "更にこのサーバーは、ディスク全体の暗号化により保護されています。",
    "This server is protected with full-disk-encryption." : "このサーバーはフルディスク暗号化で保護されています。",
    "Your files are not protected by encryption." : "ファイルは暗号化されていません。",
    "Your data is located in:" : "あなたのデータは以下の場所にあります:",
    "The admin hasn't selected the location of the server yet." : "管理者はまだサーバーの場所を選択していません。",
    "Change data location" : "データの保存場所を変更",
    "Please select a region" : "地域を選択してください",
    "You don't have any shares with individual users." : "個別のユーザーとの共有はありません",
    "Somaliland" : "ソマリランド",
    "Andorra" : "アンドラ",
    "United Arab Emirates" : "アラブ首長国連邦",
    "Afghanistan" : "アフガニスタン",
    "Antigua and Barbuda" : "アンティグア・バーブーダ",
    "Anguilla" : "アンギラ",
    "Albania" : "アルバニア",
    "Armenia" : "アルメニア",
    "Angola" : "アンゴラ",
    "Antarctica" : "南極大陸",
    "Argentina" : "アルゼンチン",
    "American Samoa" : "アメリカ領サモア",
    "Austria" : "オーストリア",
    "Australia" : "オーストラリア",
    "Aruba" : "アルバ",
    "Åland Islands" : "オーランド諸島",
    "Azerbaijan" : "アゼルバイジャン",
    "Bosnia and Herzegovina" : "ボスニア・ヘルツェゴビナ",
    "Barbados" : "バルバドス",
    "Bangladesh" : "バングラデシュ",
    "Belgium" : "ベルギー",
    "Burkina Faso" : "ブルキナファソ",
    "Bulgaria" : "ブルガリア",
    "Bahrain" : "バーレーン",
    "Burundi" : "ブルンジ共和国",
    "Benin" : "ベナン",
    "Saint Barthélemy" : "サン・バルテルミー島",
    "Bermuda" : "バミューダ諸島",
    "Brunei" : "ブルネイ",
    "Bolivia" : "ボリビア",
    "Bonaire, Sint Eustatius and Saba" : "ボネール、シント・ユースタティウスおよびサバ",
    "Brazil" : "ブラジル",
    "Bahamas" : "バハマ",
    "Bhutan" : "ブータン",
    "Bouvet Island" : "ブーベ島",
    "Botswana" : "ボツワナ",
    "Belarus" : "ベラルーシ",
    "Belize" : "ベリーズ",
    "Canada" : "カナダ",
    "Cocos (Keeling) Islands" : "ココス諸島",
    "Democratic Republic of the Congo" : "コンゴ民主共和国",
    "Central African Republic" : "中央アフリカ共和国",
    "Congo" : "コンゴ共和国",
    "Switzerland" : "スイス",
    "Cote d'Ivoire" : "コートジボワール",
    "Cook Islands" : "クック諸島",
    "Chile" : "チリ",
    "Cameroon" : "カメルーン",
    "China" : "中華人民共和国",
    "Colombia" : "コロンビア共和国",
    "Costa Rica" : "コスタリカ",
    "Cuba" : "キューバ",
    "Cabo Verde" : "カーボベルデ",
    "Curaçao" : "キュラソー島",
    "Christmas Island" : "クリスマス諸島",
    "Cyprus" : "キプロス共和国",
    "Czech" : "チェコ共和国",
    "Germany" : "ドイツ",
    "Djibouti" : "ジブチ",
    "Denmark" : "デンマーク",
    "Dominican Republic" : "ドミニカ共和国",
    "Algeria" : "アルジェリア民主人民共和国",
    "Ecuador" : "エクアドル",
    "Estonia" : "エストニア",
    "Egypt" : "エジプト",
    "West Sahara" : "西サハラ",
    "Eritrea" : "エリトリア",
    "Spain" : "スペイン",
    "Ethiopia" : "エチオピア",
    "Finland" : "フィンランド",
    "Fiji" : "フィジー",
    "Falkland Islands" : "フォークランド諸島",
    "Micronesia" : "ミクロネシア",
    "Faroe Islands" : "フェロー諸島",
    "France" : "フランス",
    "Gabon" : "ガボン",
    "United Kingdom" : "イギリス",
    "Grenada" : "グレナダ",
    "Georgia" : "ジョージア",
    "French Guiana" : "フランス領ギアナ",
    "Guernsey" : "ガーンジー",
    "Ghana" : "ガーナ",
    "Gibraltar" : "ジブラルタル",
    "Greenland" : "グリーンランド",
    "Gambia" : "ガンビア",
    "Guinea" : "ギニア共和国",
    "Guadeloupe" : "グアドループ",
    "Equatorial Guinea" : "赤道ギニア共和国",
    "Greece" : "ギリシャ",
    "South Georgia and the South Sandwich Islands" : "サウスジョージア・サウスサンドウィッチ諸島",
    "Guatemala" : "グアテマラ",
    "Guam" : "グアム",
    "Guinea-Bissau" : "ギニアビサウ共和国",
    "Guyana" : "ガイアナ",
    "Honduras" : "ホンジュラス",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "ハード島とマクドナルド諸島",
    "Croatia" : "クロアチア",
    "Haiti" : "ハイチ",
    "Hungary" : "ハンガリー",
    "Indonesia" : "インドネシア",
    "Ireland" : "アイルランド",
    "Israel" : "イスラエル",
    "Isle of Man" : "マン島",
    "India" : "インド",
    "British Indian Ocean Territory" : "イギリス領インド洋地域",
    "Iraq" : "イラク",
    "Iran" : "イラン",
    "Iceland" : "アイスランド",
    "Italy" : "イタリア",
    "Jamaica" : "ジャマイカ",
    "Jordan" : "ヨルダン・ハシミテ王国",
    "Japan" : "日本",
    "Kenya" : "ケニア",
    "Kyrgyzstan" : "キルギス",
    "Cambodia" : "カンボジア",
    "Kiribati" : "キリバス",
    "Comores" : "コモロ",
    "Saint Kitts and Nevis" : "セントクリストファー・ネイビス",
    "North Korea" : "朝鮮民主主義人民共和国",
    "South Korea" : "大韓民国",
    "Kuwait" : "クウェート",
    "Cayman Islands" : "ケイマン諸島",
    "Kazakhstan" : "カザフスタン",
    "Laos" : "ラオス",
    "Lebanon" : "レバノン",
    "Saint Lucia" : "セントルシア",
    "Liechtenstein" : "リヒテンシュタイン",
    "Sri Lanka" : "スリランカ",
    "Liberia" : "リベリア",
    "Lesotho" : "レソト",
    "Lithuania" : "リトアニア",
    "Luxembourg" : "ルクセンブルク",
    "Latvia" : "ラトビア",
    "Libya" : "リビア",
    "Morocco" : "モロッコ",
    "Monaco" : "モナコ",
    "Moldova" : "モルドバ",
    "Montenegro" : "モンテネグロ",
    "Saint Martin" : "Saint Martin",
    "Madagascar" : "マダガスカル",
    "Marshall Islands" : "マーシャル諸島",
    "Macedonia" : "北マケドニア共和国",
    "Mali" : "マリ",
    "Myanmar" : "ミャンマー",
    "Mongolia" : "モンゴル",
    "Macao" : "マカオ",
    "Northern Mariana Islands" : "北マリアナ諸島",
    "Mauritania" : "モーリタニア",
    "Montserrat" : "モントセラト",
    "Malta" : "マルタ",
    "Mauritius" : "モーリシャス",
    "Maldives" : "モルディブ",
    "Malawi" : "マラウイ共和国",
    "Mexico" : "メキシコ",
    "Malaysia" : "マレーシア",
    "Mozambique" : "モザンビーク",
    "Namibia" : "ナミビア",
    "New Caledonia" : "ニューカレドニア",
    "Niger" : "ニジェール",
    "Norfolk Island" : "ノーフォーク島",
    "Nigeria" : "ナイジェリア",
    "Nicaragua" : "ニカラグア",
    "Netherlands" : "オランダ",
    "Norway" : "ノルウェー",
    "Nepal" : "ネパール",
    "Nauru" : "ナウル",
    "Niue" : "ニウエ",
    "New Zealand" : "ニュージーランド",
    "Oman" : "オマーン",
    "Panama" : "パナマ",
    "Peru" : "ペルー",
    "French Polynesia" : "フランス領ポリネシア",
    "Papua New Guinea" : "パプアニューギニア",
    "Philippines" : "フィリピン",
    "Pakistan" : "パキスタン",
    "Poland" : "ポーランド",
    "Saint Pierre and Miquelon" : "サンピエール島・ミクロン島",
    "Pitcairn" : "ピトケアン諸島",
    "Puerto Rico" : "プエルトリコ",
    "Palestine" : "パレスチナ",
    "Portugal" : "ポルトガル",
    "Palau" : "パラオ",
    "Paraguay" : "パラグアイ",
    "Qatar" : "カタール",
    "Réunion" : "レユニオン",
    "Romania" : "ルーマニア",
    "Serbia" : "セルビア",
    "Russia" : "ロシア",
    "Rwanda" : "ルワンダ",
    "Saudi Arabia" : "サウジアラビア",
    "Solomon Islands" : "ソロモン諸島",
    "Seychelles" : "セーシェル",
    "Sudan" : "スーダン",
    "Sweden" : "スウェーデン",
    "Singapore" : "シンガポール",
    "Saint Helena, Ascension and Tristan da Cunha" : "セントヘレナ・アセンションおよびトリスタンダクーニャ",
    "Slovenia" : "スロベニア",
    "Svalbard and Jan Mayen" : "スヴァールバル諸島およびヤンマイエン島",
    "Slovakia" : "スロバキア",
    "Sierra Leone" : "シエラレオネ",
    "San Marino" : "サンマリノ",
    "Senegal" : "セネガル",
    "Somalia" : "ソマリア",
    "Suriname" : "スリナム",
    "South Sudan" : "南スーダン",
    "Sao Tome and Principe" : "サントメ・プリンシペ",
    "El Salvador" : "エルサルバドル",
    "Sint Maarten" : "シント・マールテン",
    "Syria" : "シリア",
    "Swaziland" : "スワジランド",
    "Turks and Caicos Islands" : "タークス・カイコス諸島",
    "Chad" : "チャド",
    "Fr. S. Antarctic Lands" : "フランスの南方・南極地域",
    "Togo" : "トーゴ",
    "Thailand" : "タイ",
    "Tajikistan" : "タジキスタン",
    "Tokelau" : "トケラウ",
    "Timor-Leste" : "東ティモール",
    "Turkmenistan" : "トルクメニスタン",
    "Tunisia" : "チュニジア",
    "Tonga" : "トンガ",
    "Turkey" : "トルコ",
    "Trinidad and Tobago" : "トリニダード・トバゴ",
    "Tuvalu" : "ツバル",
    "Taiwan" : "台湾",
    "Tanzania" : "タンザニア",
    "Ukraine" : "ウクライナ",
    "Uganda" : "ウガンダ",
    "United States Minor Outlying Islands" : "合衆国領有小離島",
    "United States" : "アメリカ",
    "Uruguay" : "ウルグアイ",
    "Uzbekistan" : "ウズベキスタン",
    "Holy See" : "バチカン",
    "Saint Vincent and the Grenadines" : "セントビンセント・グレナディーン",
    "Venezuela" : "ベネズエラ",
    "Virgin Islands (British)" : "イギリス領ヴァージン諸島",
    "Virgin Islands (U.S.)" : "アメリカ領ヴァージン諸島",
    "Vietnam" : "ベトナム",
    "Vanuatu" : "バヌアツ",
    "Wallis and Futuna" : "ウォリス・フツナ",
    "Samoa" : "サモア",
    "Yemen" : "イエメン",
    "Mayotte" : "マヨット",
    "South Africa" : "南アフリカ",
    "Zambia" : "ザンビア",
    "Zimbabwe" : "ジンバブエ",
    "Your Nextcloud account" : "あなたのNextcloudアカウント",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "あなたのデータにはあなたに関する情報が含まれており、簡単に悪用される可能性があります。 Nextcloudでは、あなたがあなたのデータで何が起こるかを決める権利があると信じています。 Nextcloudはユーザーデータマニフェストで定義されているようにあなたの権利を保護します！",
    "User Data Manifesto 2.0" : "ユーザーデータマニフェスト2.0",
    "Defining basic rights for people to control their own data in the internet age" : "インターネット時代に人々が自分のデータを管理するための基本的権利を定義する",
    "Control" : "コントロール",
    "over user data access" : "ユーザーデータアクセス経由",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "ユーザーによって明示的かつ意図的にアップロードされたデータは、ユーザーの最終的な管理下にあるべきです。ユーザーは、自分のデータへの直接アクセスを誰に許可するのか、およびどのアクセス権とライセンスでアクセスを許可するのかを決定できる必要があります。",
    "Knowledge" : "知見",
    "of how the data is stored" : "データの格納方法",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "データが特定のサービスプロバイダーにアップロードされるとき、ユーザーはその特定のサービスプロバイダーがデータをどのくらいの期間、どこに保存するのか、サービスプロバイダーが運営している地域、そしてどの法律が適用されるかについて知らされるべきです。",
    "Freedom" : "自由",
    "to choose a platform" : "プラットフォームを選択する",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "ユーザーはベンダーのロックインを経験することなく、いつでも自分のデータを抽出することができるはずです。これを保証するためにオープンスタンダードなフォーマットとプロトコルが必要です。",
    "Learn more ↗" : "もっと詳しく知る",
    "Where is your data?" : "データはどこにありますか？",
    "Who has access to your data?" : "誰があなたのデータにアクセスできますか？",
    "Administrators" : "管理者",
    "People you shared with" : "あなたが共有した人",
    "Privacy policy" : "個人情報保護方針",
    "Read the privacy policy." : "個人情報保護方針を読んでください。",
    "Encryption" : "暗号化",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "あなたのファイルは {linkopen}サーバーサイド暗号化↗{linkclose} で暗号化されています。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "あなたのファイルは {linkopen}サーバーサイド暗号化↗{linkclose} で暗号化されています。さらに、このサーバーはフルディスク暗号化で保護されています。",
    "Your data is located in: " : "データは以下に格納:"
},
"nplurals=1; plural=0;");
